package org.dataone.tidy.merge.strategy;

import java.io.IOException;
import java.math.BigInteger;

import org.dataone.service.exceptions.BaseException;
import org.dataone.service.exceptions.InvalidToken;
import org.dataone.service.exceptions.NotAuthorized;
import org.dataone.service.exceptions.NotFound;
import org.dataone.service.exceptions.NotImplemented;
import org.dataone.service.exceptions.ServiceFailure;
import org.dataone.service.types.v1.Checksum;
import org.dataone.service.types.v1.Identifier;
import org.dataone.service.types.v1.NodeReference;
import org.dataone.service.types.v1.ObjectFormatIdentifier;
import org.dataone.service.types.v1.Permission;
import org.dataone.service.types.v1.Subject;
import org.dataone.service.types.v1.SystemMetadata;
import org.dataone.service.types.v1.util.AccessUtil;
import org.dataone.service.util.TypeMarshaller;
import org.dataone.tidy.merge.MNSystemMetadataDelegate;
import org.jibx.runtime.JiBXException;

/**
 * A Proxy used to throw an exception of the specified type.  Allows all of the
 * dataone.BaseExceptions thrown by getSystemMEtadata, as well as NPE's and Index
 * out-of-bounds RuntimeExceptions
 * @author rnahf
 *
 */
public class ExceptionAuthMNSysmetaProxy implements MNSystemMetadataDelegate {

	private Class clazz;
	
	public ExceptionAuthMNSysmetaProxy(Class clazz) {
		this.clazz = clazz;
	}
	
	@Override
	public SystemMetadata getSystemMetadata(NodeReference nodeRef, Identifier pid)
	    throws InvalidToken, NotAuthorized, NotImplemented, ServiceFailure, NotFound 
	{
		if (clazz.equals(InvalidToken.class)) 
			throw new InvalidToken("0000","a test InvalidToken");
		
		if (clazz.equals(NotAuthorized.class)) 
			throw new NotAuthorized("0000","a test NotAuthorized");
		
		if (clazz.equals(NotImplemented.class)) 
			throw new NotImplemented("0000","a test NotImplemented");
		
		if (clazz.equals(ServiceFailure.class)) 
			throw new ServiceFailure("0000","a test ServiceFailure");
		
		if (clazz.equals(NotFound.class)) 
			throw new NotFound("0000","a test NotFound");
		
		if (clazz.equals(NullPointerException.class))
			throw new NullPointerException("a test NullPointerException");
		
		if (clazz.equals(IndexOutOfBoundsException.class))
			throw new IndexOutOfBoundsException("a test IndexOutOfBoundsException");
		
		return null;
	}

}
